summaryrefslogtreecommitdiffstats
path: root/kstyles/web
diff options
context:
space:
mode:
Diffstat (limited to 'kstyles/web')
-rw-r--r--kstyles/web/plugin.cpp4
-rw-r--r--kstyles/web/webstyle.cpp24
-rw-r--r--kstyles/web/webstyle.h14
3 files changed, 21 insertions, 21 deletions
diff --git a/kstyles/web/plugin.cpp b/kstyles/web/plugin.cpp
index c22bb08fa..bd4371ce3 100644
--- a/kstyles/web/plugin.cpp
+++ b/kstyles/web/plugin.cpp
@@ -1,9 +1,9 @@
-#include <klocale.h>
+#include <tdelocale.h>
#include "webstyle.h"
extern "C"
{
- KStyle * allocate() { return new WebStyle; }
+ TDEStyle * allocate() { return new WebStyle; }
int minor_version() { return 0; }
int major_version() { return 1; }
const char * description() { return(i18n("Web style plugin").utf8()); }
diff --git a/kstyles/web/webstyle.h b/kstyles/web/webstyle.h
index 5cd930c73..0e4c59dbd 100644
--- a/kstyles/web/webstyle.h
+++ b/kstyles/web/webstyle.h
@@ -20,7 +20,7 @@
#ifndef WEB_STYLE_H
#define WEB_STYLE_H
-#include <kstyle.h>
+#include <tdestyle.h>
#include <tqpalette.h>
class TQPainter;
@@ -28,7 +28,7 @@ class TQScrollBar;
class TQPushButton;
class TQWidget;
-class WebStyle : public KStyle
+class WebStyle : public TDEStyle
{
public:
@@ -210,7 +210,7 @@ class WebStyle : public KStyle
bool tickBelow
);
- void drawKToolBar
+ void drawTDEToolBar
(
TQPainter *,
int x,
@@ -218,7 +218,7 @@ class WebStyle : public KStyle
int w,
int h,
const TQColorGroup &,
- KToolBarPos,
+ TDEToolBarPos,
TQBrush * fill = 0
);
@@ -230,7 +230,7 @@ class WebStyle : public KStyle
int w,
int h,
const TQColorGroup &,
- KToolBarPos,
+ TDEToolBarPos,
TQBrush * fill = 0
);
@@ -246,7 +246,7 @@ class WebStyle : public KStyle
TQBrush * fill = 0
);
- void drawKToolBarButton
+ void drawTDEToolBarButton
(
TQPainter * p,
int x,
@@ -258,7 +258,7 @@ class WebStyle : public KStyle
bool raised = true,
bool enabled = true,
bool popup = false,
- KToolButtonType = Icon,
+ TDEToolButtonType = Icon,
const TQString & btext = TQString::null,
const TQPixmap * = 0,
TQFont * = 0,
diff --git a/kstyles/web/webstyle.cpp b/kstyles/web/webstyle.cpp
index ab5282e06..b3b461954 100644
--- a/kstyles/web/webstyle.cpp
+++ b/kstyles/web/webstyle.cpp
@@ -32,9 +32,9 @@
#include <tqdrawutil.h>
#include <tqpainter.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kdrawutil.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include <kiconloader.h>
#include <kdebug.h>
@@ -218,7 +218,7 @@ drawFunkyRect
}
WebStyle::WebStyle()
- : KStyle()
+ : TDEStyle()
{
setButtonDefaultIndicatorWidth(6);
setScrollBarExtent(_scrollBarExtent, _scrollBarExtent);
@@ -423,7 +423,7 @@ WebStyle::drawPushButtonLabel(TQPushButton * b, TQPainter * p)
{
// This is complicated stuff and we don't really want to mess with it.
- KStyle::drawPushButtonLabel(b, p);
+ TDEStyle::drawPushButtonLabel(b, p);
}
void
@@ -474,7 +474,7 @@ WebStyle::drawScrollBarControls
Qt::ArrowType t =
sb->orientation() == Horizontal ? Qt::RightArrow : Qt::DownArrow;
// Is it me or is KStyle::drawArrow broken ?
drawArrow
(
@@ -930,7 +930,7 @@ WebStyle::drawArrow
const TQBrush * fill
)
{
- KStyle::drawArrow(p, type, down, x, y, w, h, g, enabled, fill);
+ TDEStyle::drawArrow(p, type, down, x, y, w, h, g, enabled, fill);
}
void
@@ -965,7 +965,7 @@ WebStyle::drawSlider
}
void
-WebStyle::drawKToolBar
+WebStyle::drawTDEToolBar
(
TQPainter * p,
int x,
@@ -973,7 +973,7 @@ WebStyle::drawKToolBar
int w,
int h,
const TQColorGroup & g,
- KToolBarPos /* pos */,
+ TDEToolBarPos /* pos */,
TQBrush * /* fill */
)
{
@@ -993,7 +993,7 @@ WebStyle::drawKBarHandle
int w,
int h,
const TQColorGroup & g,
- KToolBarPos /* pos */,
+ TDEToolBarPos /* pos */,
TQBrush * /* fill */
)
{
@@ -1025,7 +1025,7 @@ WebStyle::drawKMenuBar
}
void
-WebStyle::drawKToolBarButton
+WebStyle::drawTDEToolBarButton
(
TQPainter * p,
int x,
@@ -1037,7 +1037,7 @@ WebStyle::drawKToolBarButton
bool raised,
bool enabled,
bool popup,
- KToolButtonType type,
+ TDEToolButtonType type,
const TQString & btext,
const TQPixmap * pixmap,
TQFont * font,
@@ -1308,7 +1308,7 @@ WebStyle::drawPopupMenuItem
)
{
// TODO
- KStyle::drawPopupMenuItem(p, checkable, maxpmw, tab, mi, pal, act, enabled, x, y, w, h);
+ TDEStyle::drawPopupMenuItem(p, checkable, maxpmw, tab, mi, pal, act, enabled, x, y, w, h);
}
void
@@ -474,7 +474,7 @@ WebStyle::drawScrollBarControls
Qt::ArrowType t =
sb->orientation() == Horizontal ? Qt::RightArrow : Qt::DownArrow;
- // Is it me or is KStyle::drawArrow broken ?
+ // Is it me or is TDEStyle::drawArrow broken ?
drawArrow
(